package com.persagy.dmp.define.client;

import cn.hutool.extra.spring.SpringUtil;
import com.persagy.dmp.basic.model.QueryCriteria;
import com.persagy.dmp.common.model.response.CommonResult;
import com.persagy.dmp.common.utils.ResultHelper;
import com.persagy.dmp.define.entity.ObjectInfoDefine;
import com.persagy.dmp.define.entity.ObjectTypeDefine;

import java.util.List;

/**
 * 数据字典Client门面
 * @author Charlie Yu
 * @date 2021-05-15
 */
public class DigitalDefineFacade {

    private static DigitalDefineClient client = SpringUtil.getBean(DigitalDefineClient.class);

    /**
     * 查询类型定义
     * @param groupCode 集团编码
     * @param projectId 项目ID
     * @param appId 应用ID
     * @param userId 用户ID
     * @param criteria 查询条件
     * @return 类型定义
     */
    public static List<ObjectTypeDefine> queryObjectType(String groupCode, String projectId, String appId, String userId, QueryCriteria criteria) {
        CommonResult<List<ObjectTypeDefine>> result = client.queryObjectType(groupCode, projectId, appId, userId, criteria);
        return ResultHelper.getContent(result);
    }

    /**
     * 查询对象类型-原样返回结果
     * @param groupCode 集团编码
     * @param projectId 项目ID
     * @param appId 应用ID
     * @param userId 用户ID
     * @param criteria 查询条件
     * @return 对象类型对象集合
     */
    public static CommonResult<List<ObjectTypeDefine>> queryPrototype(String groupCode, String projectId, String appId, String userId, QueryCriteria criteria) {
        return client.queryObjectType(groupCode, projectId, appId, userId, criteria);
    }

    /**
     * 创建对象类型
     * @param groupCode 集团编码
     * @param projectId 项目ID
     * @param appId 应用ID
     * @param userId 用户ID
     * @param vo 对象类型对象
     * @return 对象类型对象
     */
    public static ObjectTypeDefine create(String groupCode, String projectId, String appId, String userId, ObjectTypeDefine vo) {
        CommonResult<ObjectTypeDefine> commonResult = client.create(groupCode, projectId, appId, userId, vo);
        return commonResult.getData();
    }
    /**
     * 创建对象类型-批量新增
     * @param groupCode 集团编码
     * @param projectId 项目ID
     * @param appId 应用ID
     * @param userId 用户ID
     * @param voList 对象类型对象数组
     * @return 对象类型对象数组
     */
    public static List<ObjectTypeDefine> createBatch(String groupCode, String projectId, String appId, String userId, List<ObjectTypeDefine> voList) {
        CommonResult<List<ObjectTypeDefine>> commonResult = client.createBatch(groupCode, projectId, appId, userId, voList);
        return commonResult.getData();
    }
    /**
     * 更新对象类型
     * @param groupCode 集团编码
     * @param projectId 项目ID
     * @param appId 应用ID
     * @param userId 用户ID
     * @param vo 对象类型对象
     * @return 对象类型对象
     */
    public static ObjectTypeDefine update(String groupCode, String projectId, String appId, String userId, ObjectTypeDefine vo) {
        CommonResult<ObjectTypeDefine> commonResult = client.update(groupCode, projectId, appId, userId, vo);
        return commonResult.getData();
    }
    /**
     * 更新对象类型
     * @param groupCode 集团编码
     * @param projectId 项目ID
     * @param appId 应用ID
     * @param userId 用户ID
     * @param voList 对象类型对象数组
     * @return 对象类型对象数组
     */
    public static List<ObjectTypeDefine> updateBatch(String groupCode, String projectId, String appId, String userId, List<ObjectTypeDefine> voList) {
        CommonResult<List<ObjectTypeDefine>> commonResult = client.updateBatch(groupCode, projectId, appId, userId, voList);
        return commonResult.getData();
    }
    /**
     * 删除对象类型
     * @param groupCode 集团编码
     * @param projectId 项目ID
     * @param appId 应用ID
     * @param userId 用户ID
     * @param id 对象类型对象id
     * @return 对象类型对象
     */
    public static void delete(String groupCode, String projectId, String appId, String userId, String id) {
        client.delete(groupCode, projectId, appId, userId, id);
    }
    /**
     * 删除对象类型-批量删除
     * @param groupCode 集团编码
     * @param projectId 项目ID
     * @param appId 应用ID
     * @param userId 用户ID
     * @param ids 对象类型对象id数组
     * @return 对象类型对象数组
     */
    public static void deleteBatch(String groupCode, String projectId, String appId, String userId, List<String> ids) {
        client.deleteBatch(groupCode, projectId, appId, userId, ids);
    }
}
