package com.persagy.dmp.define.client;

import cn.hutool.extra.spring.SpringUtil;
import com.persagy.dmp.basic.model.QueryCriteria;
import com.persagy.dmp.common.model.response.CommonResult;
import com.persagy.dmp.common.utils.ResultHelper;
import com.persagy.dmp.define.entity.GraphDefine;

import java.util.List;

/**
 * 图类型Client门面
 * @author Charlie Yu
 * @date 2021-05-15
 */
public class DigitalGraphDefineFacade {

    private static DigitalGraphDefineClient client = SpringUtil.getBean(DigitalGraphDefineClient.class);

    /**
     * 查询图类型
     * @param groupCode 集团编码
     * @param projectId 项目ID
     * @param appId 应用ID
     * @param userId 用户ID
     * @param criteria 查询条件
     * @return 图类型对象集合
     */
    public static List<GraphDefine> query(String groupCode, String projectId, String appId, String userId, QueryCriteria criteria) {
        CommonResult<List<GraphDefine>> result = client.query(groupCode, projectId, appId, userId, criteria);
        return ResultHelper.getContent(result);
    }
    /**
     * 查询图类型-原样返回结果
     * @param groupCode 集团编码
     * @param projectId 项目ID
     * @param appId 应用ID
     * @param userId 用户ID
     * @param criteria 查询条件
     * @return 图类型对象集合
     */
    public static CommonResult<List<GraphDefine>> queryPrototype(String groupCode, String projectId, String appId, String userId, QueryCriteria criteria) {
        return client.query(groupCode, projectId, appId, userId, criteria);
    }
    /**
     * 创建图类型
     * @param groupCode 集团编码
     * @param projectId 项目ID
     * @param appId 应用ID
     * @param userId 用户ID
     * @param vo 图类型对象
     * @return 图类型对象
     */
    public static GraphDefine create(String groupCode, String projectId, String appId, String userId, GraphDefine vo) {
        CommonResult<GraphDefine> commonResult = client.create(groupCode, projectId, appId, userId, vo);
        return commonResult.getData();
    }
    /**
     * 更新图类型
     * @param groupCode 集团编码
     * @param projectId 项目ID
     * @param appId 应用ID
     * @param userId 用户ID
     * @param vo 图类型对象
     * @return 图类型对象
     */
    public static GraphDefine update(String groupCode, String projectId, String appId, String userId, GraphDefine vo) {
        CommonResult<GraphDefine> commonResult = client.update(groupCode, projectId, appId, userId, vo);
        return commonResult.getData();
    }
    /**
     * 删除图类型
     * @param groupCode 集团编码
     * @param projectId 项目ID
     * @param appId 应用ID
     * @param userId 用户ID
     * @param id 图类型对象id
     * @return 图类型对象
     */
    public static GraphDefine delete(String groupCode, String projectId, String appId, String userId, String id) {
        CommonResult<GraphDefine> commonResult = client.delete(groupCode, projectId, appId, userId, id);
        return commonResult.getData();
    }
}
