package com.persagy.dmp.define.client;

import com.persagy.dmp.basic.config.DigitalFeignConfig;
import com.persagy.dmp.basic.model.QueryCriteria;
import com.persagy.dmp.common.model.response.CommonResult;
import com.persagy.dmp.define.entity.GraphDefine;
import com.persagy.dmp.define.entity.ObjectInfoDefine;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;

import java.util.List;

/**
 * 对象信息点Client
 * @author Charlie Yu
 * @date 2021-05-15
 */
@FeignClient(name = "dmp-rwd", configuration = DigitalFeignConfig.class,
        url = "${persagy.bdtp.rwd.service:}",path = "/rwd/def/funcid")
public interface DigitalObjectInfoClient {

    /**
     * 查询对象信息点
     * @param groupCode: 集团编码
     * @param projectId: 项目ID
     * @param appId: 应用ID
     * @param userId: 用户ID
     * @param criteria: 查询条件
     * @return 对象信息点数组
     */
    @PostMapping("")
    CommonResult<List<ObjectInfoDefine>> query(@RequestParam("groupCode") String groupCode,
                                               @RequestParam("projectId") String projectId,
                                               @RequestParam("appId") String appId,
                                               @RequestParam("userId") String userId,
                                               @RequestBody QueryCriteria criteria);
    /**
     * 新增对象信息点对象-单个新增
     * @param groupCode: 集团编码
     * @param projectId: 项目ID
     * @param appId: 应用ID
     * @param userId: 用户ID
     * @param vo: 新增对象信息点对象
     * @return 对象信息点对象
     */
    @PostMapping("create")
    CommonResult<ObjectInfoDefine> create(@RequestParam("groupCode") String groupCode,
                                     @RequestParam("projectId") String projectId,
                                     @RequestParam("appId") String appId,
                                     @RequestParam("userId") String userId,
                                     @RequestBody ObjectInfoDefine vo);
    /**
     * 新增对象信息点对象-批量新增
     * @param groupCode: 集团编码
     * @param projectId: 项目ID
     * @param appId: 应用ID
     * @param userId: 用户ID
     * @param voList: 新增对象信息点对象数组
     * @return 对象信息点对象数组
     */
    @PostMapping("createBatch")
    CommonResult<List<ObjectInfoDefine>> createBatch(@RequestParam("groupCode") String groupCode,
                                     @RequestParam("projectId") String projectId,
                                     @RequestParam("appId") String appId,
                                     @RequestParam("userId") String userId,
                                     @RequestBody List<ObjectInfoDefine> voList);
    /**
     * 更新对象信息点对象-单个更新
     * @param groupCode: 集团编码
     * @param projectId: 项目ID
     * @param appId: 应用ID
     * @param userId: 用户ID
     * @param vo: 更新对象信息点对象
     * @return 对象信息点对象
     */
    @PostMapping("update")
    CommonResult<ObjectInfoDefine> update(@RequestParam("groupCode") String groupCode,
                                     @RequestParam("projectId") String projectId,
                                     @RequestParam("appId") String appId,
                                     @RequestParam("userId") String userId,
                                     @RequestBody ObjectInfoDefine vo);
    /**
     * 更新对象信息点对象-批量更新
     * @param groupCode: 集团编码
     * @param projectId: 项目ID
     * @param appId: 应用ID
     * @param userId: 用户ID
     * @param voList: 更新对象信息点对象数组
     * @return 对象信息点对象数组
     */
    @PostMapping("updateBatch")
    CommonResult<List<ObjectInfoDefine>> updateBatch(@RequestParam("groupCode") String groupCode,
                                     @RequestParam("projectId") String projectId,
                                     @RequestParam("appId") String appId,
                                     @RequestParam("userId") String userId,
                                     @RequestBody List<ObjectInfoDefine> voList);
    /**
     * 删除对象信息点-单个删除
     * @param groupCode: 集团编码
     * @param projectId: 项目ID
     * @param appId: 应用ID
     * @param userId: 用户ID
     * @param id: 对象信息点id
     * @return void
     */
    @PostMapping("delete")
    CommonResult<Void> delete(@RequestParam("groupCode") String groupCode,
                                     @RequestParam("projectId") String projectId,
                                     @RequestParam("appId") String appId,
                                     @RequestParam("userId") String userId,
                                     @RequestBody String id);
    /**
     * 删除对象信息点-批量删除
     * @param groupCode: 集团编码
     * @param projectId: 项目ID
     * @param appId: 应用ID
     * @param userId: 用户ID
     * @param ids: 对象信息点id数组
     * @return void
     */
    @PostMapping("deleteBatch")
    CommonResult<Void> deleteBatch(@RequestParam("groupCode") String groupCode,
                                     @RequestParam("projectId") String projectId,
                                     @RequestParam("appId") String appId,
                                     @RequestParam("userId") String userId,
                                     @RequestBody List<String> ids);

}
