package com.persagy.dmp.define.client;

import cn.hutool.extra.spring.SpringUtil;
import com.persagy.dmp.basic.model.QueryCriteria;
import com.persagy.dmp.common.model.response.CommonResult;
import com.persagy.dmp.common.utils.ResultHelper;
import com.persagy.dmp.define.entity.ObjectInfoDefine;
import com.persagy.dmp.define.entity.RelationDefine;

import java.util.List;

/**
 * 对象信息点Client门面
 * @author Charlie Yu
 * @date 2021-05-15
 */
public class DigitalObjectInfoFacade {

    private static DigitalObjectInfoClient client = SpringUtil.getBean(DigitalObjectInfoClient.class);

    /**
     * 查询对象信息点
     * @param groupCode 集团编码
     * @param projectId 项目ID
     * @param appId 应用ID
     * @param userId 用户ID
     * @param criteria 查询条件
     * @return 对象信息点对象集合
     */
    public static List<ObjectInfoDefine> query(String groupCode, String projectId, String appId, String userId, QueryCriteria criteria) {
        CommonResult<List<ObjectInfoDefine>> result = client.query(groupCode, projectId, appId, userId, criteria);
        return ResultHelper.getContent(result);
    }
    /**
     * 查询对象信息点-原样返回结果
     * @param groupCode 集团编码
     * @param projectId 项目ID
     * @param appId 应用ID
     * @param userId 用户ID
     * @param criteria 查询条件
     * @return 对象信息点对象集合
     */
    public static CommonResult<List<ObjectInfoDefine>> queryPrototype(String groupCode, String projectId, String appId, String userId, QueryCriteria criteria) {
        return client.query(groupCode, projectId, appId, userId, criteria);
    }
    /**
     * 创建对象信息点
     * @param groupCode 集团编码
     * @param projectId 项目ID
     * @param appId 应用ID
     * @param userId 用户ID
     * @param vo 对象信息点对象
     * @return 对象信息点对象
     */
    public static ObjectInfoDefine create(String groupCode, String projectId, String appId, String userId, ObjectInfoDefine vo) {
        CommonResult<ObjectInfoDefine> commonResult = client.create(groupCode, projectId, appId, userId, vo);
        return commonResult.getData();
    }
    /**
     * 创建对象信息点-批量新增
     * @param groupCode 集团编码
     * @param projectId 项目ID
     * @param appId 应用ID
     * @param userId 用户ID
     * @param voList 对象信息点对象数组
     * @return 对象信息点对象数组
     */
    public static List<ObjectInfoDefine> createBatch(String groupCode, String projectId, String appId, String userId, List<ObjectInfoDefine> voList) {
        CommonResult<List<ObjectInfoDefine>> commonResult = client.createBatch(groupCode, projectId, appId, userId, voList);
        return commonResult.getData();
    }
    /**
     * 更新对象信息点
     * @param groupCode 集团编码
     * @param projectId 项目ID
     * @param appId 应用ID
     * @param userId 用户ID
     * @param vo 对象信息点对象
     * @return 对象信息点对象
     */
    public static ObjectInfoDefine update(String groupCode, String projectId, String appId, String userId, ObjectInfoDefine vo) {
        CommonResult<ObjectInfoDefine> commonResult = client.update(groupCode, projectId, appId, userId, vo);
        return commonResult.getData();
    }
    /**
     * 更新对象信息点
     * @param groupCode 集团编码
     * @param projectId 项目ID
     * @param appId 应用ID
     * @param userId 用户ID
     * @param voList 对象信息点对象数组
     * @return 对象信息点对象数组
     */
    public static List<ObjectInfoDefine> updateBatch(String groupCode, String projectId, String appId, String userId, List<ObjectInfoDefine> voList) {
        CommonResult<List<ObjectInfoDefine>> commonResult = client.updateBatch(groupCode, projectId, appId, userId, voList);
        return commonResult.getData();
    }
    /**
     * 删除对象信息点
     * @param groupCode 集团编码
     * @param projectId 项目ID
     * @param appId 应用ID
     * @param userId 用户ID
     * @param id 对象信息点对象id
     * @return 对象信息点对象
     */
    public static void delete(String groupCode, String projectId, String appId, String userId, String id) {
        client.delete(groupCode, projectId, appId, userId, id);
    }
    /**
     * 删除对象信息点-批量删除
     * @param groupCode 集团编码
     * @param projectId 项目ID
     * @param appId 应用ID
     * @param userId 用户ID
     * @param ids 对象信息点对象id数组
     * @return 对象信息点对象数组
     */
    public static void deleteBatch(String groupCode, String projectId, String appId, String userId, List<String> ids) {
        client.deleteBatch(groupCode, projectId, appId, userId, ids);
    }
}
