package com.persagy.dmp.define.client;

import com.persagy.dmp.basic.config.DigitalFeignConfig;
import com.persagy.dmp.basic.model.QueryCriteria;
import com.persagy.dmp.common.model.response.CommonResult;
import com.persagy.dmp.define.entity.GraphDefine;
import com.persagy.dmp.define.entity.RelationDefine;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;

import java.util.List;

/**
 * 边类型Client
 * @author Charlie Yu
 * @date 2021-05-15
 */
@FeignClient(name = "dmp-rwd", configuration = DigitalFeignConfig.class,
        url = "${persagy.bdtp.rwd.service:}",path = "/rwd/def/rel")
public interface DigitalRelationDefineClient {

    /**
     * 查询边类型
     * @param groupCode: 集团编码
     * @param projectId: 项目ID
     * @param appId: 应用ID
     * @param userId: 用户ID
     * @param criteria: 查询条件
     * @return 边类型数组
     */
    @PostMapping("query")
    CommonResult<List<RelationDefine>> query(@RequestParam("groupCode") String groupCode,
                                             @RequestParam("projectId") String projectId,
                                             @RequestParam("appId") String appId,
                                             @RequestParam("userId") String userId,
                                             @RequestBody QueryCriteria criteria);
    /**
     * 新增边类型对象-单个新增
     * @param groupCode: 集团编码
     * @param projectId: 项目ID
     * @param appId: 应用ID
     * @param userId: 用户ID
     * @param vo: 新增边类型对象
     * @return 边类型对象
     */
    @PostMapping("create")
    CommonResult<RelationDefine> create(@RequestParam("groupCode") String groupCode,
                                     @RequestParam("projectId") String projectId,
                                     @RequestParam("appId") String appId,
                                     @RequestParam("userId") String userId,
                                     @RequestBody RelationDefine vo);
    /**
     * 更新边类型对象-单个更新
     * @param groupCode: 集团编码
     * @param projectId: 项目ID
     * @param appId: 应用ID
     * @param userId: 用户ID
     * @param vo: 更新边类型对象
     * @return 边类型对象
     */
    @PostMapping("update")
    CommonResult<RelationDefine> update(@RequestParam("groupCode") String groupCode,
                                     @RequestParam("projectId") String projectId,
                                     @RequestParam("appId") String appId,
                                     @RequestParam("userId") String userId,
                                     @RequestBody RelationDefine vo);
    /**
     * 删除边类型-单个删除
     * @param groupCode: 集团编码
     * @param projectId: 项目ID
     * @param appId: 应用ID
     * @param userId: 用户ID
     * @param id: 边类型id
     * @return void
     */
    @PostMapping("delete")
    CommonResult<RelationDefine> delete(@RequestParam("groupCode") String groupCode,
                                     @RequestParam("projectId") String projectId,
                                     @RequestParam("appId") String appId,
                                     @RequestParam("userId") String userId,
                                     @RequestBody String id);

}
