package com.persagy.dmp.define.client;

import cn.hutool.extra.spring.SpringUtil;
import com.persagy.dmp.basic.model.QueryCriteria;
import com.persagy.dmp.common.model.response.CommonResult;
import com.persagy.dmp.common.utils.ResultHelper;
import com.persagy.dmp.define.entity.GraphDefine;
import com.persagy.dmp.define.entity.RelationDefine;

import java.util.List;

/**
 * 边类型Client门面
 * @author Charlie Yu
 * @date 2021-05-15
 */
public class DigitalRelationDefineFacade {

    private static DigitalRelationDefineClient client = SpringUtil.getBean(DigitalRelationDefineClient.class);

    /**
     * 查询边类型
     * @param groupCode 集团编码
     * @param projectId 项目ID
     * @param appId 应用ID
     * @param userId 用户ID
     * @param criteria 查询条件
     * @return 边类型对象集合
     */
    public static List<RelationDefine> query(String groupCode, String projectId, String appId, String userId, QueryCriteria criteria) {
        CommonResult<List<RelationDefine>> result = client.query(groupCode, projectId, appId, userId, criteria);
        return ResultHelper.getContent(result);
    }
    /**
     * 查询边类型-原样返回结果
     * @param groupCode 集团编码
     * @param projectId 项目ID
     * @param appId 应用ID
     * @param userId 用户ID
     * @param criteria 查询条件
     * @return 边类型对象集合
     */
    public static CommonResult<List<RelationDefine>> queryPrototype(String groupCode, String projectId, String appId, String userId, QueryCriteria criteria) {
        return client.query(groupCode, projectId, appId, userId, criteria);
    }
    /**
     * 创建边类型
     * @param groupCode 集团编码
     * @param projectId 项目ID
     * @param appId 应用ID
     * @param userId 用户ID
     * @param vo 边类型对象
     * @return 边类型对象
     */
    public static RelationDefine create(String groupCode, String projectId, String appId, String userId, RelationDefine vo) {
        CommonResult<RelationDefine> commonResult = client.create(groupCode, projectId, appId, userId, vo);
        return commonResult.getData();
    }
    /**
     * 更新边类型
     * @param groupCode 集团编码
     * @param projectId 项目ID
     * @param appId 应用ID
     * @param userId 用户ID
     * @param vo 边类型对象
     * @return 边类型对象
     */
    public static RelationDefine update(String groupCode, String projectId, String appId, String userId, RelationDefine vo) {
        CommonResult<RelationDefine> commonResult = client.update(groupCode, projectId, appId, userId, vo);
        return commonResult.getData();
    }
    /**
     * 删除边类型
     * @param groupCode 集团编码
     * @param projectId 项目ID
     * @param appId 应用ID
     * @param userId 用户ID
     * @param id 边类型对象id
     * @return 边类型对象
     */
    public static RelationDefine delete(String groupCode, String projectId, String appId, String userId, String id) {
        CommonResult<RelationDefine> commonResult = client.delete(groupCode, projectId, appId, userId, id);
        return commonResult.getData();
    }
}
