package com.persagy.dmp.storage.service;

import lombok.SneakyThrows;

import java.util.List;
import java.util.Map;

/***
 * Description: minio通用操作处理类
 * @author : lijie
 * @date :2021/10/16 14:27
 * Update By lijie 2021/10/16 14:27
 */
public interface MinioCommonService {
    /***
     * Description: 存储桶是否存在
     * @param bucketName: 存储桶名称
     * @return true/false
     * @author : lijie
     * @date :2021/10/16 14:35
     * Update By lijie 2021/10/16 14:35
     */
    boolean isBucketExist(String bucketName);

    /***
     * Description:  创建存储桶
     * @param bucketName : 存储桶名称
     * @return : true/false
     * @author : lijie
     * @date :2021/10/16 14:35
     * Update By lijie 2021/10/16 14:35
     */
    boolean createBucket(String bucketName);

    /***
     * Description: 获取访问对象的外链地址
     * @param bucketName : 存储桶名称
     * @param objectName : 对象名称
     * @param expiry : 过期时间(分钟) 最大为7天 超过7天则默认最大值
     * @return : viewUrl
     * @author : lijie
     * @date :2021/10/16 14:41
     * Update By lijie 2021/10/16 14:41
     */
    String getObjectUrl(String bucketName, String objectName, Integer expiry);

    /***
     * Description: 创建上传文件对象的外链
     * @param bucketName : 存储桶名称
     * @param objectName : 欲上传文件对象的名称
     * @param expiry : 过期时间(分钟) 最大为7天 超过7天则默认最大值
     * @return : uploadUrl
     * @author : lijie
     * @date :2021/10/16 14:41
     * Update By lijie 2021/10/16 14:41
     */
    String createUploadUrl(String bucketName, String objectName, Integer expiry);

    /***
     * Description: 创建上传文件对象的外链
     * @param bucketName : 存储桶名称
     * @param objectName : 欲上传文件对象的名称
     * @return : java.lang.String
     * @author : lijie
     * @date :2021/10/16 14:42
     * Update By lijie 2021/10/16 14:42
     */
    String createUploadUrl(String bucketName, String objectName);
    /***
     * Description: 批量创建分片上传外链
     * @param bucketName : 存储桶名称
     * @param objectMD5 : 欲上传分片文件主文件的MD5
     * @param chunkCount : 分片数量
     * @return : uploadChunkUrls
     * @author : lijie
     * @date :2021/10/16 14:43
     * Update By lijie 2021/10/16 14:43
     */
    List<String> createUploadChunkUrlList(String bucketName, String objectMD5, Integer chunkCount);

    /***
     * Description: 创建指定序号的分片文件上传外链
     * @param bucketName : 存储桶名称
     * @param objectMD5 : 欲上传分片文件主文件的MD5
     * @param partNumber : 分片序号
     * @return : uploadChunkUrl
     * @author : lijie
     * @date :2021/10/16 14:44
     * Update By lijie 2021/10/16 14:44
     */
    String createUploadChunkUrl(String bucketName, String objectMD5, Integer partNumber);

    /***
     * Description: 获取对象文件名称列表
     * @param bucketName : 存储桶名称
     * @param prefix : 对象名称前缀
     * @param sort : 是否排序(升序)
     * @return : objectNames
     * @author : lijie
     * @date :2021/10/16 14:45
     * Update By lijie 2021/10/16 14:45
     */
    List<String> listObjectNames(String bucketName, String prefix, Boolean sort);

    /***
     * Description: 获取对象文件名称列表
     * @param bucketName : 存储桶名称
     * @param prefix : 对象名称前缀
     * @return : objectNames
     * @author : lijie
     * @date :2021/10/16 14:47
     * Update By lijie 2021/10/16 14:47
     */
    List<String> listObjectNames(String bucketName, String prefix);

    /***
     * Description: 获取分片文件名称列表
     * @param bucketName : 存储桶名称
     * @param ObjectMd5 : 对象Md5
     * @return : objectChunkNames
     * @author : lijie
     * @date :2021/10/16 14:48
     * Update By lijie 2021/10/16 14:48
     */
    List<String> listChunkObjectNames(String bucketName, String ObjectMd5);

    /***
     * Description: 获取分片名称地址HashMap key=分片序号 value=分片文件地址
     * @param bucketName : 存储桶名称
     * @param ObjectMd5 : 对象Md5
     * @return : objectChunkNameMap
     * @author : lijie
     * @date :2021/10/16 14:49
     * Update By lijie 2021/10/16 14:49
     */
    Map<Integer, String> mapChunkObjectNames(String bucketName, String ObjectMd5);

    /***
     * Description: 合并分片文件成对象文件
     * @param chunkBucKetName : 分片文件所在存储桶名称
     * @param composeBucketName : 合并后的对象文件存储的存储桶名称
     * @param chunkNames : 分片文件名称集合
     * @param objectName : 合并后的对象文件名称
     * @return : boolean
     * @author : lijie
     * @date :2021/10/16 14:50
     * Update By lijie 2021/10/16 14:50
     */
    boolean composeObject(String chunkBucKetName, String composeBucketName, List<String> chunkNames, String objectName);

    /***
     * Description: 合并分片文件成对象文件
     * @param bucketName : 存储桶名称
     * @param chunkNames : 分片文件名称集合
     * @param objectName : 合并后的对象文件名称
     * @return : true/false
     * @author : lijie
     * @date :2021/10/16 14:51
     * Update By lijie 2021/10/16 14:51
     */
    boolean composeObject(String bucketName, List<String> chunkNames, String objectName);
}
